@@ -1,35 +1,23 @@
 /*
- * Copyright (C) 2015 Aleix Pol i Gonzalez <aleixpol@blue-systems.com>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
- *
- */
+    SPDX-FileCopyrightText: 2015 Aleix Pol i Gonzalez <aleixpol@blue-systems.com>
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
 
 #include "personsproxymodeltest.h"
 
-#include <QtTest>
+#include "fakecontactsource.h"
 
-//private includes
+// private includes
 #include "personmanager_p.h"
 
-//public kpeople includes
-#include <personsmodel.h>
+// public kpeople includes
 #include <personpluginmanager.h>
+#include <personsmodel.h>
 #include <personssortfilterproxymodel.h>
 
-#include "fakecontactsource.h"
+#include <QSignalSpy>
+#include <QTest>
 
 QTEST_GUILESS_MAIN(PersonsProxyModelTest)
 
@@ -41,7 +29,7 @@ void PersonsProxyModelTest::initTestCase()
 
     // Called before the first testfunction is executed
     PersonManager::instance(m_database.fileName());
-    m_source = new FakeContactSource(nullptr); //don't own. PersonPluginManager removes it on destruction
+    m_source = new FakeContactSource(nullptr); // don't own. PersonPluginManager removes it on destruction
     QHash<QString, BasePersonsDataSource *> sources;
     sources[QStringLiteral("fakesource")] = m_source;
     PersonPluginManager::setDataSourcePlugins(sources);
