@@ -275,7 +275,7 @@ void PersonsModelPrivate::onContactsFetched()
         addPerson(MetaContact(i.key(), i.value()));
     }
 
-    for (const AllContactsMonitorPtr monitor : std::as_const(m_sourceMonitors)) {
+    for (const AllContactsMonitorPtr &monitor : std::as_const(m_sourceMonitors)) {
         connect(monitor.data(), &AllContactsMonitor::contactAdded, this, &PersonsModelPrivate::onContactAdded);
         connect(monitor.data(), &AllContactsMonitor::contactChanged, this, &PersonsModelPrivate::onContactChanged);
         connect(monitor.data(), &AllContactsMonitor::contactRemoved, this, &PersonsModelPrivate::onContactRemoved);
